@@ -224,6 +224,7 @@ class JsonFormatter(logging.Formatter):
 
     def serialize_log_record(self, log_record: Dict[str, Any]) -> str:
         """Returns the final representation of the log record."""
+        print ("123")
         return "%s%s" % (self.prefix, self.jsonify_log_record(log_record))
 
     def __add_field_in_list_from_record(self, field, event_header: List[str], record: logging.LogRecord,
@@ -371,7 +372,7 @@ class JsonFormatter(logging.Formatter):
 
         # 1. 读取配置文件
         postapi_config = configparser.ConfigParser()
-        config_file = "/etc/mr/config_5th.ini"
+        config_file = "config_5th.ini"
         postapi_config.read(config_file)
 
         api_status = postapi_config.get("global", "api_enable")
@@ -419,6 +420,6 @@ class JsonFormatter(logging.Formatter):
         event_entity = OrderedDict()
         self.create_event_entity(event_entity, record, message_dict)
         log_record['event_entity'] = event_entity
-        self.create_internal_request(log_record)
+        #self.create_internal_request(log_record)
 
         return self.serialize_log_record(log_record)
